# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/anusandhan-ml-utils',
                'doc_host': 'https://anusandhaan.github.io',
                'git_url': 'https://github.com/anusandhaan/anusandhan-ml-utils',
                'lib_path': 'anusandhan_ml_utils'},
  'syms': {'anusandhan_ml_utils.core': {'anusandhan_ml_utils.core.foo': ('core.html#foo', 'anusandhan_ml_utils/core.py')}}}
